@@ -5,9 +5,15 @@
 #include "Stream.h"
 #include "USBAPI.h"
 
+#include "utils/print.h"
+
 #if defined(USBCON)
 #ifdef CDC_ENABLED
 
+static int cdc_serial_initialised = 0;
+
+
+
 void Reboot()
 {
   printf ("Reboot called in CDC.cpp\n");
@@ -26,7 +32,7 @@ bool CDC_Setup(Setup& setup)
 int _serialPeek = -1;
 void Serial_::begin(uint16_t baud_count)
 {
-  ;
+  cdc_serial_initialised = 1;
 }
 
 void Serial_::end(void)
@@ -34,6 +40,11 @@ void Serial_::end(void)
   ;
 }
 
+void Serial_::accept(void) 
+{
+  ;
+}
+
 int Serial_::available(void)
 {
   return USB_Available(CDC_RX);
@@ -57,7 +68,14 @@ void Serial_::flush(void)
 
 size_t Serial_::write(uint8_t c)
 {
-  Serial.println(c);
+  if ( cdc_serial_initialised )
+    {
+      serial_print_c(c);
+    }
+  else
+    {
+      fprintf(stderr, "You need to call begin before using the write functions\n");
+    }
 }
 
 Serial_ Serial;
