@@ -84,6 +84,15 @@ seasim_register_lcd_cb(lcd_to_sim_callback_ptr cb)
   return ext_register_lcd_cb(cb);
 }
 
+
+char * get_lcd_data(void) ;
+
+char *
+seasim_get_lcd_data(void)
+{
+  return get_lcd_data();
+}
+
 uint8_t
 seasim_register_type_cb(pintype_to_sim_callback_ptr cb)
 {
@@ -226,6 +235,12 @@ seasim_set_board_name(char *board)
   return set_board_name(board);
 }
 
+int
+seasim_setup_board(void)
+{
+  return board_setup();
+}
+
 char *
 seasim_get_board_name(void)
 {
@@ -287,3 +302,15 @@ int seasim_set_log_level(int level)
   return searduino_set_log_level(level);
 }
 
+int 
+seasim_get_board_pins(char *board)
+{
+  return get_board_pins(board);
+}
+
+
+char * 
+seasim_get_board_setup(void)
+{
+  return get_board_setup();
+}
