@@ -63,7 +63,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
     PinTable      pins;
     Logger        serial ;
-    Logger        logger ;
+    //    Logger        logger ;
     FileLogger    fileLogger ;
     LCD           lcd ;
     InfoPanel     infoPanel;
@@ -83,6 +83,8 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
     JPanel loggerPanel;
     JPanel fileLoggerPanel;
 
+    static Jearduino jearduinoInstance ;
+
     /*
     JPanel commandPanel;
 
@@ -95,11 +97,8 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
     
     JearduinoState jState;
 
-    static int appSizeHeight = 700;
-    static int appSizeWidth  = 1080;
-
-    static int infoSizeHeight = 20;
-    static int infoSizeWidth  = 800;
+    static int appSizeHeight = 750;
+    static int appSizeWidth  = 700;
 
     public Jearduino() {
 
@@ -110,7 +109,6 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	codeNamesToStore = jpref.getArduinoCodeNameCount();
 	constraints = new GridBagConstraints();
 	
-	
 	pane = new JPanel();
 
 	JTabbedPane tabbedPane = new JTabbedPane();
@@ -121,7 +119,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
 	/*  info */
 
-	setSize(appSizeHeight, appSizeWidth);
+	setSize(appSizeWidth, appSizeHeight);
 
 
         controlPanel = new JPanel();
@@ -132,6 +130,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
 	loggerPanel = new JPanel();
 	fileLoggerPanel = new JPanel();
+	fileLoggerPanel.setLayout(new BoxLayout(fileLoggerPanel, BoxLayout.PAGE_AXIS));
 	/*
 	commandPanel = new JPanel();
 	commandPanel.setLayout(new FlowLayout(FlowLayout.CENTER));
@@ -143,8 +142,8 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
 
 	ec = new ExecControl(this);
-	controlPanel.add(ec);
-	controlPanel.setVisible(true);
+	//	ec.setBorder(BorderFactory.createTitledBorder("Execution"));
+
 	
 
 	jmenu = new JearduinoMenu(this, this, this, this, this, this);
@@ -156,40 +155,22 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	searduino = new Searduino();
 	board = new Board(this, searduino);
 	infoPanel = new InfoPanel();
-	projectPanel = new ProjectPanel();
+	//	projectPanel = new ProjectPanel();
 
-	logger    = new Logger( "Log");
+	//	controlPanel.add(projectPanel, constraints);
+	controlPanel.add(ec);
+	controlPanel.setVisible(true);
+
+	//	logger    = new Logger( "Log");
 	fileLogger = new FileLogger( "File Log", this);
 	serial = new Logger( "Serial");
 	lcd    = new LCD( "LCD");
 
-	serial.setMaximumSize(new Dimension(200, 400)); 
-	logger.setMaximumSize(new Dimension(200, 400)); 
-	//fileLogger.setMaximumSize(new Dimension(600, 800)); 
-	lcd.setMaximumSize(new Dimension(200, 400)); 
-
-	serial.setPreferredSize(new Dimension(200, 100)); 
-	logger.setPreferredSize(new Dimension(600, 150)); 
-	//fileLogger.setPreferredSize(new Dimension(600, 800)); 
-	lcd.setPreferredSize(new Dimension(200, 100)); 
-
-	/*
-	lastCommand       = new JLabel("cmd");
-	lastCommandResult = new JLabel("res");
-	lastCommandResult.setVisible(true);
-	lastCommand.setVisible(true);
-	*/
+	logPanel.add(controlPanel);
 	logPanel.add(serial);
 	logPanel.add(lcd);
-	/*
-	logPanel.add(commandPanel);
-	commandPanel.add(lastCommand);
-	commandPanel.add(lastCommandResult);
-	commandPanel.setVisible(true);
-	commandPanel.setBorder(BorderFactory.createTitledBorder("Command"));
-	*/
+	logPanel.add(infoPanel, constraints);
 
-	loggerPanel.add(logger);
 	fileLoggerPanel.add(fileLogger);
 
 	pins = new PinTable(this, jState, searduino);
@@ -215,7 +196,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	searduino.registerLogCallback(this);
 	searduino.registerLCDCallback(this);
 
-	projectPanel.setArduinoCodeName(searduino.getArduinoCodeName());
+	infoPanel.setArduinoCodeName(searduino.getArduinoCodeName());
 	infoPanel.setSearduinoVersion(searduino.getSearduinoVersion());
 
 	tabbedPane.addTab("Control", null, pane,
@@ -224,6 +205,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	tabbedPane.addTab("Log", null, fileLoggerPanel,
 			  "Log tab");
 
+	addToGUI();
 	setupSizes();
     }
 
@@ -238,7 +220,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	System.out.flush();
 	*/
 
-	logger.addLog(text);
+	//	logger.addLog(text);
 	fileLogger.addLog(text);
     }
 
@@ -247,35 +229,9 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	;
     }
 
-    public void setupSizes()
+
+    private void addToGUI() 
     {
-	/*
-	logger.setMaximumSize(new Dimension(200, 400));
-	logger.setMinimumSize(new Dimension(200, 400));
-
-	serial.setMaximumSize(new Dimension(200, 500));
-	serial.setMinimumSize(new Dimension(200, 400));
-	*/
-	projectPanel.setMinimumSize(new Dimension( 10, 300));
-	projectPanel.setMaximumSize(new Dimension( 10, 300));
-
-	infoPanel.setMinimumSize(new Dimension( 400, 50));
-	infoPanel.setMaximumSize(new Dimension( 400, 50));
-
-	pinPanel.setMaximumSize(new Dimension(400, 600));
-	pinPanel.setMinimumSize(new Dimension(400, 600));
-
-	controlPanel.setMaximumSize(new Dimension(400, 80));
-	controlPanel.setMinimumSize(new Dimension(400, 80));
-
-	logger.setMaximumSize(new Dimension(500, 300));
-	logger.setMinimumSize(new Dimension(500, 300));
-
-	loggerPanel.setMaximumSize(new Dimension(800, 300));
-	loggerPanel.setMinimumSize(new Dimension(800, 300));
-
-	serial.setMaximumSize(new Dimension(300, 300));
-	serial.setMinimumSize(new Dimension(300, 300));
 
 	int he = 0;
 
@@ -291,7 +247,6 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
 	constraints.gridwidth = 2;
 	//	System.out.println("projectPanel" + projectPanel + " c " + constraints);
-	pane.add(projectPanel, constraints);
 
 
 	/*  row  1*/
@@ -305,7 +260,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	constraints.gridy = 1;
 
 	constraints.gridwidth = 2;
-	pane.add(controlPanel, constraints);
+	//	pane.add(controlPanel, constraints);
 
 
 	/*  row  2*/
@@ -346,14 +301,35 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	pane.add(loggerPanel, constraints);
 
 
-	constraints.fill = GridBagConstraints.HORIZONTAL;
-	constraints.ipady = 0;      //
-	constraints.weightx = 0.0;
-	constraints.gridwidth = 0;
+    }
+    
+
+    private void setupSizes()
+    {
+	serial.setMaximumSize(new Dimension(200, 400)); 
+	lcd.setMaximumSize(new Dimension(200, 400)); 
+
+	serial.setPreferredSize(new Dimension(200, 100)); 
+	lcd.setPreferredSize(new Dimension(200, 100)); 
+
+	//	projectPanel.setMinimumSize(new Dimension( 100, 200));
+	//projectPanel.setMaximumSize(new Dimension( 100, 300));
+
+	infoPanel.setMinimumSize(new Dimension( 400, 50));
+	infoPanel.setMaximumSize(new Dimension( 400, 50));
+
+	pinPanel.setMaximumSize(new Dimension(400, 600));
+	pinPanel.setMinimumSize(new Dimension(400, 600));
+
+	controlPanel.setMaximumSize(new Dimension(400, 80));
+	controlPanel.setMinimumSize(new Dimension(400, 80));
+
+	loggerPanel.setMaximumSize(new Dimension(800, 300));
+	loggerPanel.setMinimumSize(new Dimension(800, 300));
+
+	serial.setMaximumSize(new Dimension(300, 300));
+	serial.setMinimumSize(new Dimension(300, 300));
 
-	constraints.gridx = 0;
-	constraints.gridy = 4;
-	pane.add(infoPanel, constraints);
 
     }
 
@@ -493,6 +469,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 		    hasDir=true;
 		}
 		useCode(new File(jState.getCanonicalCodeName()), hasDir);
+		ec.unsetStartable();
 		searduino.startArduinoCode();
 	    }
     }
@@ -617,13 +594,11 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 		
 	    }
 
-	System.out.println("\n\n======= STORE " + canonName + "==================== \n+n");
-
 	/* Store the new one in the first spot */
 	jpref.setArduinoCodeName(0, canonName);
 	
 	/* Display code name in project panel */
-	projectPanel.setArduinoCodeName(shortName);
+	infoPanel.setArduinoCodeName(shortName);
 
 	/* Update menu items */
 	showArduinoCodeNameMenu();
@@ -646,6 +621,8 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
 	addLog("useCode(" + f + ", " + hasDirectory + ")");
 
+
+	
 	try {
 	    code = f.getName();
 	    canonCode = f.getCanonicalPath();
@@ -660,17 +637,17 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	    return;
 	}
 
-
 	if (ret != 0 ) {
 	    if (jState.buildTypeStub()) {
 		setSearduinoProjectInfo(jState.getCurrentSearduinoProject(),
 					"", "");
 		showError("load Arduino code: " + f);
 	    }
-	    projectPanel.setArduinoCodeName("");
+	    infoPanel.setArduinoCodeName("");
 	    ec.unsetAll();
 	    return;
 	} else {
+	
 	    addLog("Loaded Arduino code: " + f);
 	    
 	    /* Set up pins */
@@ -686,6 +663,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 		} else {
 		    dir = "";
 		} 
+
 		setSearduinoProjectInfo(dir, code, canonCode);
 		saveArduinoCodeName(canonCode, code);
 		ec.setStartable();
@@ -695,22 +673,21 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
     public void setSearduinoProjectInfo(String project, String shortCode, String longCode) {
 
+
 	/* Manage project info */
 	if (project==null) { 
 	    project=""; 
 	}
-	if (project.equals("")) { 
-	    searduino.closeArduinoCode();
-	}
-	
+
+		
 	/* Set current project name */
 	jState.setCurrentSearduinoProject(project);
-	projectPanel.setProjectName(project);
+	infoPanel.setProjectName(project);
 
 	/* Manage code info */
 	if (shortCode!=null) {
 	    jState.setCodeName(shortCode, longCode);
-	    projectPanel.setArduinoCodeName(shortCode);
+	    infoPanel.setArduinoCodeName(shortCode);
 	}
     }
     
@@ -725,17 +702,12 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
 	addLog("Opening file: " + f);
 
-	//	System.out.println("openArduinoFileEvent -> setupBoardPins()");
-	//setupBoardPins();
-
 	try {
 	    canonFile = f.getCanonicalPath();
 	} catch (IOException e)  {
 	    showError("load Arduino code: " + f.toString());
 	    return;
 	}
-
-
 	
 	if (hasProject) {
 	    setSearduinoProjectInfo(jState.getCurrentSearduinoProject(), 
@@ -744,6 +716,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	} else {
 	    setSearduinoProjectInfo("", f.getName(),canonFile) ;
 	}
+
 	useCode(f, hasProject);
     }
 
@@ -875,8 +848,6 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 
     public void handleSearduinoDirEvent(File dir)
     {
-	stopArduinoCode(true);
-
 	getAndUseSearduinoDir(dir);
     }	
 
@@ -1006,19 +977,65 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	return searduino.getSystemInformation();
     }
 
-   public static void main(String[] args) {
 
-	final Jearduino jearduino ;
-	jearduino = new Jearduino();
+    public static Jearduino getInstance() {
+	if (jearduinoInstance==null) {
+	    jearduinoInstance = new Jearduino();
+	}
+	
+	return jearduinoInstance;
+    }
+
+    
+    public static Searduino getSearduinoInstance() {
+	return Jearduino.getInstance().searduino;
+    }
+
+
+
+    public static void usage_option(String op, String args, String desc) {
+	System.out.println("  " + op + " " + args);
+	System.out.println("   " + desc);
+	System.out.println("");
+    }
+
+    public static void usage() {
+	System.out.println("Jearduino - a graphical frontend to Searduino's simulator");
+	System.out.println("");
+	System.out.println("OPTIONS");
+	System.out.println("");
+	usage_option("--board", 
+		     "<board>", 
+		     "Set Arduino board to use");
+	usage_option("arduino-code", 
+		     "<file>", 
+		     "Set file (shared object) to execute");
+	usage_option("--searduino-project", 
+		     "<dir>", 
+		     "Loads Searduio project as found in dir");
+	usage_option("--build", 
+		     "", 
+		     "Build project after loading it");
+	usage_option("--start", 
+		     "",
+		     "Start project after loading it");
+	usage_option("--help", 
+		     "", 
+		     "Prints this message");
+    }
+
+   public static void main(String[] args) {
 
 	boolean startDirect = false;
 	boolean buildDirect = false;
 	int nrArgs     = args.length;
-	String boardS  = "<none>";
+	String boardS  = "Uno";
 	String code    = null;
 	String project = null;
 	int ret=0;
 
+	final Jearduino jearduino = Jearduino.getInstance();
+
 	for (int i=0; i<nrArgs; i++)  {
 	    if (args[i].equals("--board")) {
 		if (i+1<nrArgs) 			    {
@@ -1053,8 +1070,13 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	    else if (args[i].equals("--start")) {
 		startDirect=true;
 	    }
+	    else if (args[i].equals("--help")) {
+		usage();
+		System.exit(0);
+	    }
 	    else {
 		System.err.println("Error when pasing command line '" + args[i] + "'");
+		System.err.println("  Start with '--help' for help");
 		System.exit(1);
 	    }
 	}
@@ -1093,7 +1115,6 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	//	if (jearduino.validBoard()) {
 
 	if ( jearduino.isBoardSupported(boardS)) {
-	    
 	    ret = jearduino.setupBoard(boardS);
 	} else {
 	    System.out.println ("You supplied an unsupported board: " 
@@ -1104,24 +1125,26 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 	    System.exit(1);
 	}
 	
+
 	if (project!=null) {
 	    jearduino.handleSearduinoDirEvent(new File(project));
 	} else if (code!=null) {
+	    jearduino.setSearduinoProjectInfo("", "", code) ;
 	    jearduino.getAndUseArduinoCodeName(code, false);
 	} else {
 	    /* If no code supplied on cli - use latest */
 	    jearduino.getAndUseArduinoCodeName(null, false);
 	}
 	
-
-	    if (buildDirect) {
-		jearduino.handleJearduinoEvent(JearduinoEvent.JEARDUINO_EVENT_BUILD_PROJECT, null);
-	    }
-	    
-	    if (startDirect) {
-		jearduino.ec.sendStart();
-	    }
-	    //}
+	
+	if (buildDirect) {
+	    jearduino.handleJearduinoEvent(JearduinoEvent.JEARDUINO_EVENT_BUILD_PROJECT, null);
+	}
+	
+	if (startDirect) {
+	    jearduino.ec.sendStart();
+	}
+	//}
 
         SwingUtilities.invokeLater(new Runnable() {
 		public void run() {
@@ -1129,4 +1152,7 @@ public class Jearduino extends JFrame implements SearduinoObserver, ExecEvent, P
 		}
 	    });
     }
+    
+    
+
 }
