@@ -32,13 +32,13 @@ read_file()
     fi
 }
 
-SEARDUINO_PATH=/tmp/hesa/TMP_INSTALL3
+SEARDUINO_PATH=/opt/searduino
 SEARDUINO_SHARE=${SEARDUINO_PATH}/share/searduino/
 read_file ${SEARDUINO_SHARE}/scripts/settings
 read_file ${SEARDUINO_SHARE}/scripts/functions
 
 
-export PATH=/tmp/hesa/TMP_INSTALL3/bin:${PATH}
+export PATH=/opt/searduino/bin:${PATH}
 
 SIM_BIN="${0/\.sh/}-sim"
 
